@@ -2,10 +2,16 @@
 
 import sys, os
 import glob
-from depth_temp_log_io import *
-from photo_tagging import *
-from gps_log_io import *
-from bps_export import *
+try:
+    from benthic_photo_survey.depth_temp_log_io import *
+    from benthic_photo_survey.photo_tagging import *
+    from benthic_photo_survey.gps_log_io import *
+    from benthic_photo_survey.bps_export import *
+except ImportError:
+    from depth_temp_log_io import *
+    from photo_tagging import *
+    from gps_log_io import *
+    from bps_export import *
 from PyQt4 import QtCore
 from PyQt4.QtGui import QApplication, QMainWindow, QFileDialog, QPixmap, \
     QMessageBox
